Description:
============

Presentation
------------
Ramses is an open source code to model astrophysical systems, featuring self-gravitating, magnetised, compressible, radiative fluid flows. It is based on the Adaptive Mesh Refinement (AMR) technique on a fully-threaded graded octree. ramses is written in Fortran 90 and is making intensive use of the Message Passing Interface (MPI) library.

Technical information:
----------------------

* website : https://www.ics.uzh.ch/~teyssier/ramses/RAMSES.html
* Scientific domain : Astrophysics
* Language : Fortran 90
* Parallelism : MPI 
* GPU acceleration : No
* Scalability : high -> To verify
* Vectorization: ?


Compilation and simulation:
===========================

Here we describe the different phases from the download to the validation of the simulation.

Download:
---------

The ramses version used is based on the stable\_18\_09 version (see git bitbucket https://bitbucket.org/rteyssie/ramses). Home-made modifications (made by the ramses developers) have been made to be able to start from an evolved system, and make a verifiable benchmark (currently impossible with the official). The patch concerns inputs and outputs and routines representing less than 1% of the computing time. In the official distributions, on large simulations the i/o parameters are written in the checkpoints and are not read back in the namelist. 

More informations can be found directly on https://bitbucket.org/rteyssie/ramses/overview

1. The first step, if the input and the test case are not available on the machine, is to download ramses, inputs and  tests cases :
```
$ ls -1 /store/CINES/dci/SHARED/abs/ramses/
input_big.tar
input.tar
PROD_BIG.tar
PROD.tar
ramses.tar.gz
testcase_small.tar.gz
```
with:
* input_big.tar: Big test case
* input.tar: Medium test case
* PROD_BIG.tar: contains the namelist used for the big test case
* PROD.tar: contains the namelist used for the medium test case
* ramses.tar.gz: The ramses version patched as explained above
* testcase_small.tar.gz: small test case with the namelist inside

2. The second step is to edit env script which include:
* ramses_dir: root directory of ramses executable
* bench_dir: root directory of the bench folder
* environments variables if needed (like MPIF90, F90, ...)

3. Then, you can use the following script to unload the pre-imported/pre-downloaded version of ramses.
```
./download.sh
```

Compile:
--------

Compile the code using the bash script:
```
./compile.sh
```

Run and validate the simulation:
--------------------------------

For each test case, given in a separate folder (e.g. testcase_small), you can find three scripts:

*  prepare.sh: prepare the simulation (move data to the right location, recompile some minor changes, ...)
*  run.sh : run the application and print out the evaluated metric
*  validate.sh: validation of the simulation on a scientific point of view

For running and validating the simulation, one should be able to do:
```
cd testcase_XXX
./prepare.sh
./run.sh
./validate.sh
```
And getting no error code returned.
Those steps can also be used in a batch file for running the simulation using a job scheduler.

***Run:***
Information about jobs to be launched can be found in the READ.md file of each test case (testcase_small, testcase_medium and testcase_large).

***Validation:***
- Metric: The metric used to bench is the total time of the simulation in seconds excluding initialization and I/Os. (For more details see the validate.sh script). 
- physical: ? (TODO)
